/**
 * PrefActivity.java
 * Copyright (C) 2012 Pattern Recognition Lab, University Erlangen-Nuremberg.
 *  
 * Licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License (the "License");
 * you may not use this file except in compliance with the License.
 * To view a copy of this License, visit http://creativecommons.org/licenses/by-nc-sa/3.0/.
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on 
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the 
 * specific language governing permissions and limitations under the License.
 * 
 * 
 * This file is part of the "Hearty" Android Application. It was released as supplementary material related to the publication [1]:
 * [1] S. Gradl, P. Kugler, C. Lohmüller, and B. Eskofier, “Real-time ECG monitoring and arrhythmia detection using Android-based mobile devices,” in 34th Annual International Conference of the IEEE EMBS, 2012, pp. 2452–2455.
 * 
 * It is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * If you reuse this code you have to keep or cite this comment.
 *
 */
package de.lme.hearty;


import android.app.Dialog;
import android.content.Intent;
import android.os.Bundle;
import android.preference.Preference;
import android.preference.Preference.OnPreferenceClickListener;
import android.preference.PreferenceActivity;
import android.preference.PreferenceManager;




/**
 * @author Stefan Gradl
 */
public class PrefActivity extends PreferenceActivity implements Preference.OnPreferenceChangeListener,
		Preference.OnPreferenceClickListener
{
	@Override
	protected void onCreate (Bundle savedInstanceState)
	{
		super.onCreate( savedInstanceState );

		addPreferencesFromResource( R.xml.pref_plots );


		// pref.setOnPreferenceClickListener( this );
		// pref.setDefaultValue( defaultValue )
	}


	/* (non-Javadoc)
	 * @see android.app.Activity#onResume()
	 */
	@Override
	protected void onResume ()
	{
		Preference pref = (Preference) findPreference( "pk_bt" );
		pref.setOnPreferenceClickListener( new OnPreferenceClickListener() {

			public boolean onPreferenceClick (Preference preference)
			{
				PrefActivity.this.startActivityForResult( new Intent( getApplicationContext(), DeviceListActivity.class ), 22 );
				return false;
			}
		} );
		super.onResume();
	}


	/* (non-Javadoc)
	 * @see android.preference.PreferenceActivity#onActivityResult(int, int, android.content.Intent)
	 */
	@Override
	protected void onActivityResult (int requestCode, int resultCode, Intent data)
	{
		if (requestCode == 22)
		{
			if (resultCode == RESULT_OK)
			{
				String addr = data.getStringExtra( DeviceListActivity.EXTRA_DEVICE_ADDRESS );
				if (addr != null && addr.length() > 1)
				{
					Preference pref = (Preference) findPreference( "pk_bt" );
					pref.setSummary( addr );
					PreferenceManager.getDefaultSharedPreferences( this ).edit().putString( "pk_source", "blue" )
							.putString( "pk_bt_source", addr ).commit();
				}
			}
		}
		super.onActivityResult( requestCode, resultCode, data );
	}


	@Override
	protected void onPause ()
	{
		super.onPause();
	}


	/* (non-Javadoc)
	* @see android.preference.Preference.OnPreferenceChangeListener#onPreferenceChange(android.preference.Preference, java.lang.Object)
	*/
	public boolean onPreferenceChange (Preference arg0, Object arg1)
	{
		// TODO Auto-generated method stub
		return false;
	}


	/* (non-Javadoc)
	* @see android.app.Activity#onCreateDialog(int)
	*/
	@Override
	protected Dialog onCreateDialog (int id)
	{
		Dialog dialog = null;

		return dialog;
	}


	/* (non-Javadoc)
	* @see android.preference.Preference.OnPreferenceClickListener#onPreferenceClick(android.preference.Preference)
	*/
	public boolean onPreferenceClick (Preference preference)
	{
		String key = preference.getKey();
		if (key != null && key.equals( "pk_xx" ))
		{
			// Space.startActivity( Space.appContext, Space.ACTION_MONITOR_CALIBRATE, null, 0 );
			return true;
		}

		return false;
	}
}
