/**
 * ShimmerManager.java
 * Copyright (C) 2012 Pattern Recognition Lab, University Erlangen-Nuremberg.
 *  
 * Licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 Unported License (the "License");
 * you may not use this file except in compliance with the License.
 * To view a copy of this License, visit http://creativecommons.org/licenses/by-nc-sa/3.0/.
 * 
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on 
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the 
 * specific language governing permissions and limitations under the License.
 * 
 * 
 * This file is part of the "Hearty" Android Application. It was released as supplementary material related to the publication [1]:
 * [1] S. Gradl, P. Kugler, C. Lohmüller, and B. Eskofier, “Real-time ECG monitoring and arrhythmia detection using Android-based mobile devices,” in 34th Annual International Conference of the IEEE EMBS, 2012, pp. 2452–2455.
 * 
 * It is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * If you reuse this code you have to keep or cite this comment.
 *
 */
package de.lme.hearty;


import java.util.HashSet;
import java.util.Set;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;



/**
 * @author Patrick Kugler
 */
public class ShimmerManager extends Object
{
	private final BluetoothAdapter	mmBluetoothAdapter;


	public ShimmerManager ()
	{
		mmBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
	}


	public Set< ShimmerDataSource > getShimmerDevices ()
	{
		Set< ShimmerDataSource > mmShimmerDevices;
		mmShimmerDevices = new HashSet< ShimmerDataSource >();
		mmShimmerDevices.clear();

		Set< BluetoothDevice > pairedDevices = mmBluetoothAdapter.getBondedDevices();

		if (pairedDevices.size() > 0)
		{
			for (BluetoothDevice device : pairedDevices)
			{
				mmShimmerDevices.add( new ShimmerConnectDevice( device ) );
			}
		}

		return mmShimmerDevices;
	}


	public ShimmerDataSource getShimmerDeviceByID (String id)
	{
		Set< BluetoothDevice > pairedDevices = mmBluetoothAdapter.getBondedDevices();

		// mBluetoothAdapter.getRemoteDevice(address);

		if (pairedDevices.size() > 0)
		{
			for (BluetoothDevice device : pairedDevices)
			{
				if (device.getName().equals( id ))
					return new ShimmerConnectDevice( device );
			}
		}

		return null;
	}

}